# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'EmailTemplate'
        db.create_table(u'classy_mail_emailtemplate', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=64)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=512)),
            ('subject_content', self.gf('django.db.models.fields.CharField')(max_length=512)),
            ('text_content', self.gf('django.db.models.fields.TextField')()),
            ('html_content', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'classy_mail', ['EmailTemplate'])

        # Adding model 'CampaignAddressee'
        db.create_table(u'classy_mail_campaignaddressee', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True, blank=True)),
            ('email_address', self.gf('django.db.models.fields.EmailField')(unique=True, max_length=75)),
            ('first_name', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
            ('last_name', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
        ))
        db.send_create_signal(u'classy_mail', ['CampaignAddressee'])

        # Adding model 'EmailCampaign'
        db.create_table(u'classy_mail_emailcampaign', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=64)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=512)),
            ('template_name', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
            ('subject_content', self.gf('django.db.models.fields.CharField')(max_length=512, null=True, blank=True)),
            ('text_content', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('html_content', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'classy_mail', ['EmailCampaign'])

        # Adding M2M table for field emails on 'EmailCampaign'
        m2m_table_name = db.shorten_name(u'classy_mail_emailcampaign_emails')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('emailcampaign', models.ForeignKey(orm[u'classy_mail.emailcampaign'], null=False)),
            ('campaignaddressee', models.ForeignKey(orm[u'classy_mail.campaignaddressee'], null=False))
        ))
        db.create_unique(m2m_table_name, ['emailcampaign_id', 'campaignaddressee_id'])

        # Adding model 'CampaignMail'
        db.create_table(u'classy_mail_campaignmail', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('campaign', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['classy_mail.EmailCampaign'])),
            ('adressee', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['classy_mail.CampaignAddressee'])),
            ('date_sent', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('date_opened', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('date_clicked', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'classy_mail', ['CampaignMail'])


    def backwards(self, orm):
        # Deleting model 'EmailTemplate'
        db.delete_table(u'classy_mail_emailtemplate')

        # Deleting model 'CampaignAddressee'
        db.delete_table(u'classy_mail_campaignaddressee')

        # Deleting model 'EmailCampaign'
        db.delete_table(u'classy_mail_emailcampaign')

        # Removing M2M table for field emails on 'EmailCampaign'
        db.delete_table(db.shorten_name(u'classy_mail_emailcampaign_emails'))

        # Deleting model 'CampaignMail'
        db.delete_table(u'classy_mail_campaignmail')


    models = {
        u'auth.group': {
            'Meta': {'object_name': 'Group'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        u'auth.permission': {
            'Meta': {'ordering': "(u'content_type__app_label', u'content_type__model', u'codename')", 'unique_together': "((u'content_type', u'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['contenttypes.ContentType']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        u'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        u'classy_mail.campaignaddressee': {
            'Meta': {'object_name': 'CampaignAddressee'},
            'email_address': ('django.db.models.fields.EmailField', [], {'unique': 'True', 'max_length': '75'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['auth.User']", 'null': 'True', 'blank': 'True'})
        },
        u'classy_mail.campaignmail': {
            'Meta': {'object_name': 'CampaignMail'},
            'adressee': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['classy_mail.CampaignAddressee']"}),
            'campaign': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['classy_mail.EmailCampaign']"}),
            'date_clicked': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'date_opened': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'date_sent': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        u'classy_mail.emailcampaign': {
            'Meta': {'object_name': 'EmailCampaign'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '512'}),
            'emails': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['classy_mail.CampaignAddressee']", 'symmetrical': 'False'}),
            'html_content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '64'}),
            'subject_content': ('django.db.models.fields.CharField', [], {'max_length': '512', 'null': 'True', 'blank': 'True'}),
            'template_name': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'}),
            'text_content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'})
        },
        u'classy_mail.emailtemplate': {
            'Meta': {'object_name': 'EmailTemplate'},
            'description': ('django.db.models.fields.CharField', [], {'max_length': '512'}),
            'html_content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '64'}),
            'subject_content': ('django.db.models.fields.CharField', [], {'max_length': '512'}),
            'text_content': ('django.db.models.fields.TextField', [], {})
        },
        u'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['classy_mail']